#!/usr/bin/python
#
# File: soapserver.py
# (c) 2006 Jan Dittberner <jan@dittberner.info>
# $Id$
#
from SOAPpy import SOAPServer
import logging

class GnuviechAdminSOAPServer(SOAPServer):
    """
    SOAP Server class for the gnuviech administration tool backend
    """
    def echo(self, param0):
        """
        This method echoes its parameter
        """
        self.logger.debug("calling echo with " + param0)
        return param0 + param0
    
    def __init__(self):
        """
        This method creates the SOAPServer and registers the methods to be
        available to connected SOAP clients.
        """
        SOAPServer.__init__(self, ("127.0.0.1", 8080))
        self.logger = logging.getLogger('GnuviechAdminSOAPServer')
        hdlr = logging.FileHandler('soapserver.log')
        hdlr.setFormatter(logging.Formatter('%(asctime)s %(levelname)s %(message)s'))
        self.logger.addHandler(hdlr)
        self.logger.setLevel(logging.DEBUG)
        self.logger.debug("created SOAPServer")
        self.registerFunction(self.echo)
        self.logger.debug("registered function echo")
        
    def main(self):
        """
        Starts serving SOAP requests.
        """
        self.logger.debug("serving SOAP")
        self.serve_forever()
        
if __name__ == "__main__":
    server = GnuviechAdminSOAPServer()
    server.main()